LinuxNativeImpl class sealed

Accepted by NitroModule.linux.

Valid constant:

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

cpp → const LinuxNativeImpl
Direct C++ via CMake/GCC/Clang. The only valid implementation for Linux.