ZeroCopyInt16Buffer class

Zero-copy buffer backed by int16_t* — maps to Int16List.

Constructors

ZeroCopyInt16Buffer(Pointer<Int16> ptr, int length, void nativeRelease())

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
final
ptr Pointer<Int16>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Int16List
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
Explicitly releases native memory before GC.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited