nativePort property
int
get
nativePort
The port id to hand to the WASM submit call so its coalescer can address this demuxer.
Implementation
int get nativePort => _port.sendPort.nativePort;
The port id to hand to the WASM submit call so its coalescer can address this demuxer.
int get nativePort => _port.sendPort.nativePort;