WebSendPort class final
Facade mirroring SendPort for WebReceivePort.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nativePort → int
-
The int port id handed to the WASM module — the web analog of
SendPort.nativePort.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
dynamic message) → void -
Local delivery, mirroring
SendPort.send(used by tests to inject messages without a WASM module). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited