ZeroCopyUint16Buffer class
Buffer of uint16_t — maps to Uint16List.
Constructors
- ZeroCopyUint16Buffer.fromSnapshot(Uint16List _snapshot)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- values → Uint16List
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → void -
API parity with the native buffers; the native allocation was already
returned at construction, so this only flips the guard.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited