menu
nitro package
documentation
nitro.dart
NitroAsync class
NitroAsync class
dark_mode
light_mode
NitroAsync
class
Constructors
NitroAsync
({
int
?
timeout
})
const
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
timeout
→
int
?
Optional timeout in milliseconds. When set, the async method will throw a TimeoutException if the native call takes longer than
timeout
ms. null = no timeout.
final
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
nitro package
documentation
nitro
NitroAsync class
nitro library