NitroNullableDouble class

Collision-free nullable double for Nitro bridges.

Wire format: 8B: value (float64_le) = 9 bytes

Unlike double? (NaN sentinel), every double value is representable — including double.nan, double.infinity, -double.infinity, and 0.0.

Available extensions

Constructors

NitroNullableDouble({required bool hasValue, required double value})
const
NitroNullableDouble.fromNullable(double? v)
factory

Properties

asDouble double?

Available on NitroNullableDouble, provided by the NitroNullableDoubleExt extension

no setter
hashCode int
The hash code for this object.
no setteroverride
hasValue bool
final
nullable double?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative(Allocator alloc) Pointer<Uint8>

Available on NitroNullableDouble, provided by the NitroNullableDoubleNative extension

toString() String
A string representation of this object.
override
writeFields(RecordWriterBase writer) → void

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

nullValue → const NitroNullableDouble